@@ -1,3 +1,4 @@
+import sys
 import os
 from pathlib import Path
 import shutil
@@ -8,6 +9,8 @@ import typer
 
 app = typer.Typer()
 
+VENV_NAME = "magic_venv"
+
 
 @app.command()
 def sowell():
@@ -27,22 +30,9 @@ def download_boilerplate_git_folder(output_filename):
                 f.write(chunk)
 
 
-def run_from_scratch(project_path: str):
-
-    # first chdir into it
-    os.chdir(project_path)
-
-    # then create venv and activate it
-    os.system("which python")
-
-    os.system("python3 -m venv venv")
-    os.system(
-        "source venv/bin/activate && which python && pip install -r requirements.txt && python main.py"
-    )
-
-    # os.system("which python")
-
-    # then pip install requirements
+def make_venv():
+    os.system(f"python3 -m venv {VENV_NAME}")
+    os.system(f"source {VENV_NAME}/bin/activate && pip install -r requirements.txt")
 
 
 @app.command()
@@ -73,14 +63,23 @@ def create(project_name: str = typer.Argument("magic-server"), replace: bool = F
 
 
 @app.command()
-def dev():
+def dev(create_venv: bool = True):
     main_filename = "main.py"
     if not Path(main_filename).exists():
         typer.echo(
             "Cannot find the main.py file. Are you sure you created this app with magic?"
         )
         raise typer.Exit()
-    os.system(f"export LOCAL=1 && python {main_filename}")
+
+    command = f"export LOCAL=1 && python {main_filename}"
+
+    prefix = getattr(sys, "prefix", "")
+    if VENV_NAME not in prefix and create_venv:
+        typer.echo("no venv detected, will make own now")
+        make_venv()
+        command = f"source {VENV_NAME}/bin/activate && {command}"
+
+    os.system(command)
 
 
 if __name__ == "__main__":
